@@ -40,13 +40,39 @@ public class StoragePoolValidatorTest {
     }
 
     @Test
-    public void testIsUpdValid() {
-        assertThat("Storage pool should be up", validator.isUp(), isValid());
+    public void testExistsValid() {
+        assertThat("Storage pool should exist", validator.exists(), isValid());
     }
 
     @Test
-    public void testIsUpdInvalid() {
+    public void testExistsInvalid() {
+        validator = new StoragePoolValidator(null);
+        assertThat(validator.exists(), failsWith(EngineMessage.ACTION_TYPE_FAILED_STORAGE_POOL_NOT_EXIST));
+    }
+
+    @Test
+    public void testExistsAndUpValid() {
+        assertThat("Storage pool should be up", validator.existsAndUp(), isValid());
+    }
+
+    @Test
+    public void testExistAndUpInvalid() {
         storagePool.setStatus(StoragePoolStatus.NonResponsive);
-        assertThat(validator.isUp(), failsWith(EngineMessage.ACTION_TYPE_FAILED_IMAGE_REPOSITORY_NOT_FOUND));
+        assertThat(validator.existsAndUp(), failsWith(EngineMessage.ACTION_TYPE_FAILED_STORAGE_POOL_STATUS_ILLEGAL));
+    }
+
+    @Test
+    public void testIsInStatusValid() {
+        assertThat(validator.isInStatus(StoragePoolStatus.Up, StoragePoolStatus.Contend), isValid());
+        assertThat(validator.isNotInStatus(StoragePoolStatus.Up, StoragePoolStatus.Contend),
+                failsWith(EngineMessage.ACTION_TYPE_FAILED_STORAGE_POOL_STATUS_ILLEGAL));
+    }
+
+    @Test
+    public void testIsInStatusInvalid() {
+        assertThat(validator.isInStatus(StoragePoolStatus.NonResponsive, StoragePoolStatus.NotOperational),
+                failsWith(EngineMessage.ACTION_TYPE_FAILED_STORAGE_POOL_STATUS_ILLEGAL));
+        assertThat(validator.isNotInStatus(StoragePoolStatus.NonResponsive, StoragePoolStatus.NotOperational),
+                isValid());
     }
 }
