@@ -30,13 +30,13 @@ import org.ovirt.engine.api.resource.ClusterResource;
 import org.ovirt.engine.api.restapi.resource.AbstractBackendCollectionResourceTest;
 import org.ovirt.engine.api.restapi.resource.AbstractBackendResource;
 import org.ovirt.engine.api.restapi.resource.BackendResource;
-import org.ovirt.engine.core.common.action.VdcActionType;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.gluster.GlusterVolumeBricksActionParameters;
 import org.ovirt.engine.core.common.action.gluster.GlusterVolumeRemoveBricksParameters;
 import org.ovirt.engine.core.common.businessentities.gluster.GlusterBrickEntity;
 import org.ovirt.engine.core.common.queries.IdQueryParameters;
-import org.ovirt.engine.core.common.queries.VdcQueryReturnValue;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
+import org.ovirt.engine.core.common.queries.QueryReturnValue;
+import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.common.queries.gluster.GlusterVolumeAdvancedDetailsParameters;
 import org.ovirt.engine.core.compat.Guid;
 
@@ -194,14 +194,14 @@ public class BackendGlusterBricksResourceTest extends AbstractBackendCollectionR
     }
 
     private void setUpBrickCreationExpectation(boolean force) {
-        setUpCreationExpectations(VdcActionType.AddBricksToGlusterVolume,
+        setUpCreationExpectations(ActionType.AddBricksToGlusterVolume,
                 GlusterVolumeBricksActionParameters.class,
                 new String[] { "VolumeId", "Bricks", "Force" },
                 new Object[] { volumeId, getBricks(), force },
                 true,
                 true,
                 getBrickIds(),
-                VdcQueryType.GetGlusterBrickById,
+                QueryType.GetGlusterBrickById,
                 IdQueryParameters.class,
                 new String[] { "Id" },
                 new Object[] { GUIDS[0] },
@@ -210,13 +210,13 @@ public class BackendGlusterBricksResourceTest extends AbstractBackendCollectionR
 
     @Test
     public void testRemove() throws Exception {
-        setUpGetEntityExpectations(VdcQueryType.GetGlusterVolumeById,
+        setUpGetEntityExpectations(QueryType.GetGlusterVolumeById,
                 IdQueryParameters.class,
                 new String[] { "Id" },
                 new Object[] { volumeId },
                 helper.getVolumeEntity(0));
 
-        setUriInfo(setUpActionExpectations(VdcActionType.GlusterVolumeRemoveBricks,
+        setUriInfo(setUpActionExpectations(ActionType.GlusterVolumeRemoveBricks,
                 GlusterVolumeRemoveBricksParameters.class,
                 new String[] { "VolumeId", "Bricks" },
                 new Object[] { volumeId, getBrickEntitiesToRemove() },
@@ -229,13 +229,13 @@ public class BackendGlusterBricksResourceTest extends AbstractBackendCollectionR
 
     @Test
     public void testRemoveCommit() throws Exception {
-        setUpGetEntityExpectations(VdcQueryType.GetGlusterVolumeById,
+        setUpGetEntityExpectations(QueryType.GetGlusterVolumeById,
                 IdQueryParameters.class,
                 new String[] { "Id" },
                 new Object[] { volumeId },
                 helper.getVolumeEntity(1));
 
-        setUriInfo(setUpActionExpectations(VdcActionType.CommitRemoveGlusterVolumeBricks,
+        setUriInfo(setUpActionExpectations(ActionType.CommitRemoveGlusterVolumeBricks,
                 GlusterVolumeRemoveBricksParameters.class,
                 new String[] {},
                 new Object[] {},
@@ -257,7 +257,7 @@ public class BackendGlusterBricksResourceTest extends AbstractBackendCollectionR
         GlusterBricks bricks = mock(GlusterBricks.class);
         when(bricks.getGlusterBricks()).thenReturn(Collections.singletonList(brick));
 
-        setUriInfo(setUpActionExpectations(VdcActionType.StartRemoveGlusterVolumeBricks,
+        setUriInfo(setUpActionExpectations(ActionType.StartRemoveGlusterVolumeBricks,
                 GlusterVolumeRemoveBricksParameters.class,
                 new String[] {},
                 new Object[] {},
@@ -280,7 +280,7 @@ public class BackendGlusterBricksResourceTest extends AbstractBackendCollectionR
         GlusterBricks bricks = mock(GlusterBricks.class);
         when(bricks.getGlusterBricks()).thenReturn(Collections.singletonList(brick));
 
-        setUriInfo(setUpActionExpectations(VdcActionType.StopRemoveGlusterVolumeBricks,
+        setUriInfo(setUpActionExpectations(ActionType.StopRemoveGlusterVolumeBricks,
                 GlusterVolumeRemoveBricksParameters.class,
                 new String[] {},
                 new Object[] {},
@@ -303,7 +303,7 @@ public class BackendGlusterBricksResourceTest extends AbstractBackendCollectionR
         GlusterBricks bricks = mock(GlusterBricks.class);
         when(bricks.getGlusterBricks()).thenReturn(Collections.singletonList(brick));
 
-        setUriInfo(setUpActionExpectations(VdcActionType.StopRemoveGlusterVolumeBricks,
+        setUriInfo(setUpActionExpectations(ActionType.StopRemoveGlusterVolumeBricks,
                 GlusterVolumeRemoveBricksParameters.class,
                 new String[] {},
                 new Object[] {},
@@ -421,26 +421,25 @@ public class BackendGlusterBricksResourceTest extends AbstractBackendCollectionR
     }
 
     private void setUpBricksQueryExpectations(Object failure) {
-        VdcQueryReturnValue queryResult = mock(VdcQueryReturnValue.class);
-        when(queryResult.getSucceeded()).thenReturn(failure == null);
+        QueryReturnValue queryResult = new QueryReturnValue();
+        queryResult.setSucceeded(failure == null);
         List<GlusterBrickEntity> entities = new ArrayList<>();
 
         if (failure == null) {
             for (int i = 0; i < NAMES.length; i++) {
                 entities.add(getEntity(i));
             }
-            when(queryResult.getReturnValue()).thenReturn(entities);
+            queryResult.setReturnValue(entities);
         } else {
             if (failure instanceof String) {
-                when(queryResult.getExceptionString()).thenReturn((String) failure);
+                queryResult.setExceptionString((String) failure);
                 setUpL10nExpectations((String) failure);
             } else if (failure instanceof Exception) {
-                when(backend.runQuery(eq(VdcQueryType.GetGlusterVolumeBricks), any(IdQueryParameters.class))).thenThrow((Exception) failure);
+                when(backend.runQuery(eq(QueryType.GetGlusterVolumeBricks), any())).thenThrow((Exception) failure);
                 return;
             }
         }
-        when(backend.runQuery(eq(VdcQueryType.GetGlusterVolumeBricks), any(IdQueryParameters.class))).thenReturn(
-                queryResult);
+        when(backend.runQuery(eq(QueryType.GetGlusterVolumeBricks), any())).thenReturn(queryResult);
     }
 
     private void setUpGetEntityExpectationsAllContent(boolean notFound) throws Exception {
@@ -453,13 +452,13 @@ public class BackendGlusterBricksResourceTest extends AbstractBackendCollectionR
 
     private void setupEntityExpectationAdvancedDetails(int times, boolean notFound) throws Exception {
         while (times-- > 0) {
-            setUpGetEntityExpectations(VdcQueryType.GetGlusterVolumeById,
+            setUpGetEntityExpectations(QueryType.GetGlusterVolumeById,
                     IdQueryParameters.class,
                     new String[] { "Id" },
                     new Object[] { volumeId },
                     helper.getVolumeEntity(0));
 
-            setUpGetEntityExpectations(VdcQueryType.GetGlusterVolumeAdvancedDetails,
+            setUpGetEntityExpectations(QueryType.GetGlusterVolumeAdvancedDetails,
                     GlusterVolumeAdvancedDetailsParameters.class,
                     new String[] { "ClusterId", "VolumeId", "BrickId", "DetailRequired" },
                     new Object[] { clusterId, volumeId, GUIDS[times], true },
